==> postgresql_contrib-8.3.7-i586-P1.tgz: install/doinst.sh <==
#%% begin initialize postgresql_contrib-8.3.7-i586-P1
export PATH=/bin:/usr/bin:/sbin:/usr/sbin
chown -R postgres:pgsql $ROOT/opt/pgsql/doc/contrib/
chown postgres:pgsql $ROOT/opt/pgsql/lib/adminpack.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/btree_gist.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/chkpass.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/cube.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/dblink.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/earthdistance.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/fuzzystrmatch.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/hstore.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/int_aggregate.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/_int.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/isn.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/lo.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/ltree.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pg_buffercache.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pg_freespacemap.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pg_trgm.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pgcrypto.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pgrowlocks.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pgstattuple.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/seg.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/autoinc.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/insert_username.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/moddatetime.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/refint.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/timetravel.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/tablefunc.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/tsearch2.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/sslinfo.so
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_adminpack.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/adminpack.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_btree_gist.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/btree_gist.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_chkpass.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/chkpass.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_cube.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/cube.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_dblink.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/dblink.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_earthdistance.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/earthdistance.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_fuzzystrmatch.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/fuzzystrmatch.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_hstore.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/hstore.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_int_aggregate.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/int_aggregate.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall__int.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/_int.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_isn.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/isn.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_lo.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/lo.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_ltree.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/ltree.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pg_buffercache.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pg_buffercache.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pg_freespacemap.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pg_freespacemap.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pg_trgm.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pg_trgm.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pgcrypto.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pgcrypto.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pgrowlocks.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pgrowlocks.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pgstattuple.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pgstattuple.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_seg.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/seg.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/autoinc.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/insert_username.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/moddatetime.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/refint.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/timetravel.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_tablefunc.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/tablefunc.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/tsearch2.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_tsearch2.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_sslinfo.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/sslinfo.sql
chown postgres:pgsql $ROOT/opt/pgsql/lib/dict_int.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/dict_xsyn.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pgxml.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pageinspect.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/test_parser.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/uuid-ossp.so  
chown postgres:pgsql $ROOT/opt/pgsql/share/tsearch_data
chown postgres:pgsql $ROOT/opt/pgsql/share/tsearch_data/xsyn_sample.rules
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_dict_int.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/dict_int.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_dict_xsyn.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/dict_xsyn.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pgxml.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pgxml.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pageinspect.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pageinspect.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_test_parser.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/test_parser.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_uuid-ossp.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uuid-ossp.sql
chown postgres:pgsql $ROOT/opt/pgsql/bin/oid2name
chown postgres:pgsql $ROOT/opt/pgsql/bin/pgbench
chown postgres:pgsql $ROOT/opt/pgsql/bin/vacuumlo
chown -R postgres:pgsql $ROOT/opt/pgsql/apps/contrib/
chown -R root:root $ROOT/usr/share/doc/postgresql-8.3.7/contrib/
#%% end

==> postgresql_contrib-8.4.1-i586-P1.tgz: install/doinst.sh <==
#%% begin initialize postgresql_contrib-8.4.1-i586-P1
export PATH=/bin:/usr/bin:/sbin:/usr/sbin
chown -R postgres:pgsql $ROOT/opt/pgsql/share/doc/contrib/
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_adminpack.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/adminpack.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_btree_gin.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/btree_gin.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_btree_gist.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/btree_gist.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_chkpass.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/chkpass.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_citext.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/citext.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_cube.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/cube.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_dblink.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/dblink.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_dict_int.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/dict_int.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_dict_xsyn.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/dict_xsyn.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_earthdistance.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/earthdistance.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_fuzzystrmatch.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/fuzzystrmatch.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_hstore.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/hstore.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/int_aggregate.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_int_aggregate.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall__int.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/_int.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_isn.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/isn.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_lo.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/lo.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_ltree.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/ltree.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pageinspect.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pageinspect.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pg_buffercache.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pg_buffercache.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pg_freespacemap.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pg_freespacemap.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pg_stat_statements.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pg_stat_statements.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pg_trgm.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pg_trgm.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pgcrypto.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pgcrypto.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pgrowlocks.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pgrowlocks.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pgstattuple.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pgstattuple.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_seg.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/seg.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/autoinc.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/insert_username.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/moddatetime.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/refint.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/timetravel.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_tablefunc.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/tablefunc.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_test_parser.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/test_parser.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_tsearch2.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/tsearch2.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_sslinfo.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/sslinfo.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_uuid-ossp.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uuid-ossp.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/uninstall_pgxml.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/contrib/pgxml.sql
chown postgres:pgsql $ROOT/opt/pgsql/share/tsearch_data/xsyn_sample.rules
chown postgres:pgsql $ROOT/opt/pgsql/lib/adminpack.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/auto_explain.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/btree_gin.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/btree_gist.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/chkpass.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/citext.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/cube.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/dblink.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/dict_int.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/dict_xsyn.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/earthdistance.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/fuzzystrmatch.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/hstore.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/_int.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/isn.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/lo.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/ltree.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pageinspect.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pg_buffercache.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pg_freespacemap.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pg_stat_statements.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pg_trgm.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pgcrypto.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pgrowlocks.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pgstattuple.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/seg.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/autoinc.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/insert_username.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/moddatetime.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/refint.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/timetravel.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/tablefunc.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/test_parser.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/tsearch2.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/sslinfo.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/uuid-ossp.so
chown postgres:pgsql $ROOT/opt/pgsql/lib/pgxml.so
chown postgres:pgsql $ROOT/opt/pgsql/bin/oid2name
chown postgres:pgsql $ROOT/opt/pgsql/bin/pg_standby
chown postgres:pgsql $ROOT/opt/pgsql/bin/pgbench
chown postgres:pgsql $ROOT/opt/pgsql/bin/vacuumlo
chown -R postgres:pgsql $ROOT/opt/pgsql/apps/contrib/
chown -R root:root $ROOT/usr/share/doc/postgresql-8.4.1/contrib/
#%% end
